/*
  $Id: ForceUpdateControl.java 2623 2013-02-19 22:09:07Z dfisher $

  Copyright (C) 2003-2013 Virginia Tech.
  All rights reserved.

  SEE LICENSE FOR MORE INFORMATION

  Author:  Middleware Services
  Email:   middleware@vt.edu
  Version: $Revision: 2623 $
  Updated: $Date: 2013-02-19 17:09:07 -0500 (Tue, 19 Feb 2013) $
*/
package org.ldaptive.ad.control;

import org.ldaptive.LdapUtils;
import org.ldaptive.control.AbstractControl;
import org.ldaptive.control.RequestControl;

/**
 * Request control for active directory servers to perform an update even if the
 * data is already the same. See
 * http://msdn.microsoft.com/en-us/library/cc223344.aspx
 *
 * @author  Middleware Services
 * @version  $Revision: 2623 $ $Date: 2013-02-19 17:09:07 -0500 (Tue, 19 Feb 2013) $
 */
public class ForceUpdateControl extends AbstractControl
  implements RequestControl
{

  /** OID of this control. */
  public static final String OID = "1.2.840.113556.1.4.1974";

  /** hash code seed. */
  private static final int HASH_CODE_SEED = 971;


  /** Default constructor. */
  public ForceUpdateControl()
  {
    super(OID);
  }


  /**
   * Creates a new force update control.
   *
   * @param  critical  whether this control is critical
   */
  public ForceUpdateControl(final boolean critical)
  {
    super(OID, critical);
  }


  /** {@inheritDoc} */
  @Override
  public int hashCode()
  {
    return
      LdapUtils.computeHashCode(HASH_CODE_SEED, getOID(), getCriticality());
  }


  /** {@inheritDoc} */
  @Override
  public String toString()
  {
    return
      String.format(
        "[%s@%d::criticality=%s]",
        getClass().getName(),
        hashCode(),
        getCriticality());
  }


  /** {@inheritDoc} */
  @Override
  public byte[] encode()
  {
    return null;
  }
}
