/*
  $Id: FastBindOperation.java 2733 2013-06-11 19:04:30Z dfisher $

  Copyright (C) 2003-2013 Virginia Tech.
  All rights reserved.

  SEE LICENSE FOR MORE INFORMATION

  Author:  Middleware Services
  Email:   middleware@vt.edu
  Version: $Revision: 2733 $
  Updated: $Date: 2013-06-11 15:04:30 -0400 (Tue, 11 Jun 2013) $
*/
package org.ldaptive.ad.extended;

import org.ldaptive.AbstractOperation;
import org.ldaptive.Connection;
import org.ldaptive.ConnectionInitializer;
import org.ldaptive.LdapException;
import org.ldaptive.Response;

/**
 * Executes an active directory fast bind operation. See
 * http://msdn.microsoft.com/en-us/library/cc223503(v=prot.20).aspx.
 *
 * @author  Middleware Services
 * @version  $Revision: 2733 $ $Date: 2013-06-11 15:04:30 -0400 (Tue, 11 Jun 2013) $
 */
public class FastBindOperation extends AbstractOperation<FastBindRequest, Void>
{


  /**
   * Creates a new fast bind operation.
   *
   * @param  conn  connection
   */
  public FastBindOperation(final Connection conn)
  {
    super(conn);
  }


  /** {@inheritDoc} */
  @Override
  protected Response<Void> invoke(final FastBindRequest request)
    throws LdapException
  {
    @SuppressWarnings("unchecked") final Response<Void> response =
      (Response<Void>)
        getConnection().getProviderConnection().extendedOperation(request);
    return response;
  }


  /** Connection initializer that executes the {@link FastBindOperation}. */
  public static class FastBindConnectionInitializer
    implements ConnectionInitializer
  {


    /** {@inheritDoc} */
    @Override
    public Response<Void> initialize(final Connection c)
      throws LdapException
    {
      final FastBindOperation op = new FastBindOperation(c);
      op.setOperationExceptionHandler(null);
      return op.execute(new FastBindRequest());
    }
  }
}
