/*
  $Id: OperationWorker.java 2592 2013-01-28 23:01:42Z dfisher $

  Copyright (C) 2003-2013 Virginia Tech.
  All rights reserved.

  SEE LICENSE FOR MORE INFORMATION

  Author:  Middleware Services
  Email:   middleware@vt.edu
  Version: $Revision: 2592 $
  Updated: $Date: 2013-01-28 18:01:42 -0500 (Mon, 28 Jan 2013) $
*/
package org.ldaptive.concurrent;

import java.util.Collection;
import java.util.concurrent.Future;
import org.ldaptive.Request;
import org.ldaptive.Response;

/**
 * Interface for ldap operation workers. Operation workers leverage the
 * java.util.concurrent package to execute non-blocking operations.
 *
 * @param  <Q>  type of ldap request
 * @param  <S>  type of ldap response
 *
 * @author  Middleware Services
 * @version  $Revision: 2592 $ $Date: 2013-01-28 18:01:42 -0500 (Mon, 28 Jan 2013) $
 */
public interface OperationWorker<Q extends Request, S>
{


  /**
   * Execute an ldap operation on a separate thread.
   *
   * @param  request  containing the data required by this operation
   *
   * @return  future response for this operation
   */
  Future<Response<S>> execute(Q request);


  /**
   * Execute an ldap operation for each request on a separate thread.
   *
   * @param  requests  containing the data required by this operation
   *
   * @return  future responses for this operation
   */
  Collection<Future<Response<S>>> execute(Q... requests);


  /**
   * Execute an ldap operation for each request on a separate thread and waits
   * for each operation to complete.
   *
   * @param  requests  containing the data required by this operation
   *
   * @return  responses for this operation
   */
  Collection<Response<S>> executeToCompletion(Q... requests);
}
