/*
  $Id: ExtendedResponseFactory.java 2581 2013-01-02 21:16:24Z dfisher $

  Copyright (C) 2003-2013 Virginia Tech.
  All rights reserved.

  SEE LICENSE FOR MORE INFORMATION

  Author:  Middleware Services
  Email:   middleware@vt.edu
  Version: $Revision: 2581 $
  Updated: $Date: 2013-01-02 16:16:24 -0500 (Wed, 02 Jan 2013) $
*/
package org.ldaptive.extended;

import org.ldaptive.ad.extended.FastBindRequest;
import org.ldaptive.ad.extended.FastBindResponse;

/**
 * Utility class for creating extended responses.
 *
 * @author  Middleware Services
 * @version  $Revision: 2581 $ $Date: 2013-01-02 16:16:24 -0500 (Wed, 02 Jan 2013) $
 */
public final class ExtendedResponseFactory
{


  /** Default constructor. */
  private ExtendedResponseFactory() {}


  /**
   * Creates an extended response from the supplied response data.
   *
   * @param  requestOID  of the extended request
   * @param  responseOID  of the extended response
   * @param  encoded  BER encoding of the extended response
   *
   * @return  extended response
   */
  public static ExtendedResponse<?> createExtendedResponse(
    final String requestOID,
    final String responseOID,
    final byte[] encoded)
  {
    ExtendedResponse<?> res;
    if (PasswordModifyRequest.OID.equals(requestOID)) {
      res = new PasswordModifyResponse();
      if (encoded != null) {
        res.decode(encoded);
      }
    } else if (WhoAmIRequest.OID.equals(requestOID)) {
      res = new WhoAmIResponse();
      if (encoded != null) {
        res.decode(encoded);
      }
    } else if (CancelRequest.OID.equals(requestOID)) {
      res = new CancelResponse();
    } else if (FastBindRequest.OID.equals(requestOID)) {
      res = new FastBindResponse();
    } else {
      throw new IllegalArgumentException("Unknown OID: " + responseOID);
    }
    return res;
  }
}
