/*
  $Id: UnsolicitedNotifications.java 2610 2013-02-07 23:22:09Z dfisher $

  Copyright (C) 2003-2013 Virginia Tech.
  All rights reserved.

  SEE LICENSE FOR MORE INFORMATION

  Author:  Middleware Services
  Email:   middleware@vt.edu
  Version: $Revision: 2610 $
  Updated: $Date: 2013-02-07 18:22:09 -0500 (Thu, 07 Feb 2013) $
*/
package org.ldaptive.extended;

import org.ldaptive.Connection;

/**
 * Adds and removes unsolicited notification listeners to provider connections.
 *
 * @author  Middleware Services
 * @version  $Revision: 2610 $ $Date: 2013-02-07 18:22:09 -0500 (Thu, 07 Feb 2013) $
 */
public class UnsolicitedNotifications
{

  /** Connection to configure unsolicited notifications on. */
  private final Connection connection;


  /**
   * Creates a new unsolicited notifications.
   *
   * @param  conn  connection
   */
  public UnsolicitedNotifications(final Connection conn)
  {
    connection = conn;
  }


  /**
   * Adds a listener to receive unsolicited notifications.
   *
   * @param  listener  to receive unsolicited notifications
   */
  public void addListener(final UnsolicitedNotificationListener listener)
  {
    connection.getProviderConnection().addUnsolicitedNotificationListener(
      listener);
  }


  /**
   * Removes a listener from receiving unsolicited notifications.
   *
   * @param  listener  to no longer receive unsolicited notifications
   */
  public void removeListener(final UnsolicitedNotificationListener listener)
  {
    connection.getProviderConnection().removeUnsolicitedNotificationListener(
      listener);
  }
}
