/*
  $Id: BindConnectionInitializerPropertyInvoker.java 2591 2013-01-25 16:15:19Z dfisher $

  Copyright (C) 2003-2013 Virginia Tech.
  All rights reserved.

  SEE LICENSE FOR MORE INFORMATION

  Author:  Middleware Services
  Email:   middleware@vt.edu
  Version: $Revision: 2591 $
  Updated: $Date: 2013-01-25 11:15:19 -0500 (Fri, 25 Jan 2013) $
*/
package org.ldaptive.props;

import org.ldaptive.Credential;
import org.ldaptive.control.RequestControl;
import org.ldaptive.sasl.SaslConfig;

/**
 * Handles properties for {@link org.ldaptive.BindConnectionInitializer}.
 *
 * @author  Middleware Services
 * @version  $Revision: 2591 $ $Date: 2013-01-25 11:15:19 -0500 (Fri, 25 Jan 2013) $
 */
public class BindConnectionInitializerPropertyInvoker
  extends AbstractPropertyInvoker
{


  /**
   * Creates a new bind connection initializer property invoker for the supplied
   * class.
   *
   * @param  c  class that has setter methods
   */
  public BindConnectionInitializerPropertyInvoker(final Class<?> c)
  {
    initialize(c);
  }


  /** {@inheritDoc} */
  @Override
  protected Object convertValue(final Class<?> type, final String value)
  {
    Object newValue = value;
    if (type != String.class) {
      if (SaslConfig.class.isAssignableFrom(type)) {
        if ("null".equals(value)) {
          newValue = null;
        } else {
          if (PropertyValueParser.isParamsOnlyConfig(value)) {
            final PropertyValueParser configParser = new PropertyValueParser(
              value,
              "org.ldaptive.sasl.SaslConfig");
            newValue = configParser.initializeType();
          } else if (PropertyValueParser.isConfig(value)) {
            final PropertyValueParser configParser = new PropertyValueParser(
              value);
            newValue = configParser.initializeType();
          } else {
            newValue = instantiateType(SaslConfig.class, value);
          }
        }
      } else if (RequestControl[].class.isAssignableFrom(type)) {
        newValue = createArrayTypeFromPropertyValue(
          RequestControl.class,
          value);
      } else if (Credential.class.isAssignableFrom(type)) {
        newValue = new Credential(value);
      } else {
        newValue = convertSimpleType(type, value);
      }
    }
    return newValue;
  }
}
