/*
  $Id: SearchIterator.java 2581 2013-01-02 21:16:24Z dfisher $

  Copyright (C) 2003-2013 Virginia Tech.
  All rights reserved.

  SEE LICENSE FOR MORE INFORMATION

  Author:  Middleware Services
  Email:   middleware@vt.edu
  Version: $Revision: 2581 $
  Updated: $Date: 2013-01-02 16:16:24 -0500 (Wed, 02 Jan 2013) $
*/
package org.ldaptive.provider;

import org.ldaptive.LdapException;
import org.ldaptive.Response;

/**
 * Search results iterator.
 *
 * @author  Middleware Services
 * @version  $Revision: 2581 $ $Date: 2013-01-02 16:16:24 -0500 (Wed, 02 Jan 2013) $
 */
public interface SearchIterator
{


  /**
   * Returns true if the iteration has more elements.
   *
   * @return  true if the iterator has more elements
   *
   * @throws  LdapException  if an error occurs
   */
  boolean hasNext()
    throws LdapException;


  /**
   * Returns the next element in the iteration.
   *
   * @return  the next element in the iteration
   *
   * @throws  LdapException  if an error occurs
   */
  SearchItem next()
    throws LdapException;


  /**
   * Returns the response data associated with this search or null if this
   * iterator has more ldap entries to return.
   *
   * @return  response data
   */
  Response<Void> getResponse();


  /**
   * Close any resources associated with this iterator.
   *
   * @throws  LdapException  if an error occurs
   */
  void close()
    throws LdapException;
}
