/*
  $Id: CredentialConfig.java 2581 2013-01-02 21:16:24Z dfisher $

  Copyright (C) 2003-2013 Virginia Tech.
  All rights reserved.

  SEE LICENSE FOR MORE INFORMATION

  Author:  Middleware Services
  Email:   middleware@vt.edu
  Version: $Revision: 2581 $
  Updated: $Date: 2013-01-02 16:16:24 -0500 (Wed, 02 Jan 2013) $
*/
package org.ldaptive.ssl;

import java.security.GeneralSecurityException;

/**
 * Provides a base interface for all credential configurations. Since credential
 * configs are invoked via reflection by the PropertyInvoker their method
 * signatures are not important. They only need to be able to create an SSL
 * context initializer once their properties have been set.
 *
 * @author  Middleware Services
 * @version  $Revision: 2581 $ $Date: 2013-01-02 16:16:24 -0500 (Wed, 02 Jan 2013) $
 */
public interface CredentialConfig
{


  /**
   * Creates an SSL context initializer using the configured trust and
   * authentication material in this config.
   *
   * @return  SSL context initializer
   *
   * @throws  GeneralSecurityException  if the ssl context initializer cannot be
   * created
   */
  SSLContextInitializer createSSLContextInitializer()
    throws GeneralSecurityException;
}
